==> google_map_fluttify-0.0.1.tar.gz: example/lib/map/draw_on_map/draw_circle.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:google_map_fluttify/google_map_fluttify.dart';
import 'package:google_map_fluttify_example/utils/next_latlng.dart';

class DrawCircleScreen extends StatefulWidget {
  DrawCircleScreen();

  factory DrawCircleScreen.forDesignTime() => DrawCircleScreen();

  @override
  _DrawCircleScreenState createState() => _DrawCircleScreenState();
}

class _DrawCircleScreenState extends State<DrawCircleScreen> with NextLatLng {
  GoogleMapController _controller;
  List<Circle> _circleList = [];

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('绘制圆')),
      body: DecoratedColumn(
        children: <Widget>[
          Flexible(
            flex: 1,
            child: GoogleMapView(
              onMapCreated: (controller) async {
                _controller = controller;
              },
            ),
          ),
          Flexible(
            child: DecoratedColumn(
              divider: kDividerTiny,
              children: <Widget>[
                ListTile(
                  title: Center(child: Text('添加圆')),
                  onTap: () async {
                    final circle = await _controller?.addCircle(CircleOption(
                      center: LatLng(39.999391, 116.135972),
                      radius: 10000,
                      width: 10,
                      strokeColor: Colors.green,
                    ));
                    _circleList.add(circle);
                  },
                ),
                ListTile(
                  title: Center(child: Text('删除圆')),
                  onTap: () async {
                    if (_circleList.isNotEmpty) {
                      await _circleList.first.remove();
                      _circleList.removeAt(0);
                    }
                  },
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}

==> google_map_fluttify-0.0.9.tar.gz: example/lib/map/draw_on_map/draw_circle.screen.dart <==
import 'package:decorated_flutter/decorated_flutter.dart';
import 'package:flutter/material.dart';
import 'package:google_map_fluttify/google_map_fluttify.dart';
import 'package:google_map_fluttify_example/utils/next_latlng.dart';

class DrawCircleScreen extends StatefulWidget {
  DrawCircleScreen();

  factory DrawCircleScreen.forDesignTime() => DrawCircleScreen();

  @override
  _DrawCircleScreenState createState() => _DrawCircleScreenState();
}

class _DrawCircleScreenState extends State<DrawCircleScreen> with NextLatLng {
  GoogleMapController _controller;
  final List<ICircle> _circleList = [];

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('绘制圆')),
      body: DecoratedColumn(
        children: <Widget>[
          Flexible(
            flex: 1,
            child: GoogleMapView(
              onMapCreated: (controller) async {
                _controller = controller;
              },
            ),
          ),
          Flexible(
            child: DecoratedColumn(
              divider: kDivider1,
              children: <Widget>[
                ListTile(
                  title: Center(child: Text('添加圆')),
                  onTap: () async {
                    final circle = await _controller?.addCircle(CircleOption(
                      center: LatLng(39.999391, 116.135972),
                      radius: 10000,
                      width: 10,
                      strokeColor: Colors.green,
                    ));
                    _circleList.add(circle);
                  },
                ),
                ListTile(
                  title: Center(child: Text('删除圆')),
                  onTap: () async {
                    if (_circleList.isNotEmpty) {
                      await _circleList.first.remove();
                      _circleList.removeAt(0);
                    }
                  },
                ),
              ],
            ),
          ),
        ],
      ),
    );
  }
}
